@@ -363,18 +363,24 @@ def ProcessBatch(sourcefolder, outputfolder,
                 f.write('\n')
                 
         count = 0
-        for file in file_list:
+	missed_images = []
+        for file in image_list:
             try:
                 Process1Image(file, sourcefolder, outputfolder,
                      corners, s = s, array_dimensions = array_dimensions, pin_size = pin_size,
                      adjust = adjust, rotate = rotate, save = True, display = False)
                 count = count+1
             except:
+		missed_images.append(file)
                 continue
                 
         file_object = open(os.path.join(outputfolder,'BatchParameters.txt'), 'a')
         file_object.write(str(count)+' out of '+ str(len(file_list))+ ' images processed.')
         file_object.close()
+	with open(os.path.join(outputfolder,'MissedImages.txt'), 'w') as f:
+            for image in missed_images:
+                f.write(image)
+                f.write('\n')
     return None
     
  
@@ -466,6 +472,7 @@ def ParallelProcessBatch(sourcefolder, outputfolder, numThreads = 2,
     # -- Define workhorse function with input arguments
     def workMethod(tno, workQueue):
         count = 0
+	missed_images = []
         for item in workQueue:
             # ... process item ... #
             print("[Thread %d] Processing item '%s'" % (tno, str(item)))
@@ -475,12 +482,20 @@ def ParallelProcessBatch(sourcefolder, outputfolder, numThreads = 2,
                              adjust = adjust, rotate = rotate, save = True, display = False)
                 count = count + 1
             except:
+		missed_images.append(file)
                 continue
         print("[Thread %d] Processed '%s' out of '%s' images" % (tno, str(count),str(len(workQueue))))
         file_object = open(os.path.join(outputfolder,'BatchParameters.txt'), 'a')
-        file_object.write(str(count)+' out of '+ str(len(file_list))+ ' images processed on thread ' + str(tno)+'.')
+        file_object.write(str(count)+' out of '+ str(len(workQueue))+ ' images processed on thread ' + str(tno)+'.')
+	file_object.write('\n')
         file_object.close()
+        
+        with open(os.path.join(outputfolder,'MissedImages.txt'), 'w') as f:
+            for image in missed_images:
+                f.write(image)
+                f.write('\n')
         return None
+
     
     # -- Set Up Folders
     wd = os.getcwd()
